Learn R Programming

choroplethr (version 5.0.1)

country.map: An sf containing geometry data for countries of the world

Description

An sf containing geometry data for countries of the world

Usage

data(country.map)

Arguments

References

Data obtained using the ne_countries function from rnaturalearth;
https://github.com/ropensci/rnaturalearth,
https://www.naturalearthdata.com/