df_state_demographics: A data.frame containing demographic statistics for each state...

df_state_demographicsR Documentation

A data.frame containing demographic statistics for each state plus the District of Columbia.

Description

A data.frame containing demographic statistics for each state plus the District of Columbia.

Usage

data(df_state_demographics)

References

Data comes from the 2013 5-year American Community Survey (ACS).
Data generated by get_state_demographics().


choroplethr documentation built on Sept. 12, 2026, 1:06 a.m.