state.map.hex: An sf containing a hexagonal tile map for US states

state.map.hexR Documentation

An sf containing a hexagonal tile map for US states

Description

An sf containing a hexagonal tile map for US states

Usage

data(state.map.hex)

References

obtained from: Cedric Scherer's Github


choroplethr documentation built on Sept. 12, 2026, 1:06 a.m.