Learn R Programming

choroplethr (version 5.0.1)

state.map.hires: An sf containing higher resolution geometry data for US states

Description

An sf containing higher resolution geometry data for US states

Usage

data(state.map.hires)

Arguments

References

obtained using tigris::states()