Creates a choropleth of US states using the US Census' American Community Survey (ACS) data.
state_choropleth_acs(
variable = NULL,
tableId = NULL,
column_idx = NULL,
endyear,
span = 5,
title = NULL,
census_api_key = NULL,
...
)A choropleth.
The variable you wish to plot. A list of available census variables can be obtained using tidycensus::load_variables()
Alternatively, you may specify the ACS table you wish to plot. If the table has more than one variable inside it, you must also specify the index of the column you wish to plot.
The index of the desired column within the table.
The end year of the survey to use.
Either 1, 3, or 5, the ACS vintage you wish to use.
A title for the plot; if not specified, a title will be assigned based on the variable.
Optional. Census API keys can be obtained at:
https://api.census.gov/data/key_signup.html
Other arguments passed to state_choropleth; see ?state_choropleth()