zip_lookup: A dataset that maps zip codes to counties, states, and CBSAs

zip_lookupR Documentation

A dataset that maps zip codes to counties, states, and CBSAs

Description

A dataset that maps zip codes to counties, states, and CBSAs

Usage

data(zip_lookup)

References

Data obtained from Census Department


choroplethr documentation built on Sept. 12, 2026, 1:06 a.m.